@@ -1,4 +1,4 @@
-from typing import Optional, List, Tuple
+from typing import List, Tuple
 from parchmint.params import Params
 from parchmint.port import Port
 from parchmint.layer import Layer
@@ -6,8 +6,8 @@ from parchmint.layer import Layer
 
 class Component:
     def __init__(self, json=None):
-        self.name: Optional[str] = None
-        self.ID: Optional[str] = None
+        self.name: str = ""
+        self.ID: str = ""
         self.params = Params()
         self.entity: str = ""
         self.xpos: int = -1
@@ -50,12 +50,12 @@ class Component:
         return {
             "name": self.name,
             "id": self.ID,
-            "layers": self.layers,
+            "layers": [layer.ID for layer in self.layers],
             "params": self.params.to_parchmint_v1(),
             "ports": [p.to_parchmint_v1() for p in self.ports],
             "entity": self.entity,
-            "x-span": self.xspan,
-            "y-span": self.yspan,
+            "x-span": int(self.xspan),
+            "y-span": int(self.yspan),
         }
 
     def __eq__(self, obj):
